==> fts-1.3.zip: fts/src/org/logical_paradox/fts/KeywordLocationArray.java <==
/*
 * KeywordLocationzƂĊǗRNV
 */
package org.logical_paradox.fts;

import java.util.Iterator;

import org.logical_paradox.common.vrm.Record;

/**
 * KeywordLocationzŊǗRNV
 * ̃RNV̂Record̃TuNXƂāCVRMňƂł
 * 
 * @author satoshi akabane@logical-paradox.org
 * @version 1.0
 */
public class KeywordLocationArray extends Record {
	/**
	 * RXgN^
	 */
	public KeywordLocationArray() {
		o = new KeywordLocationArrayListByteStream();
	}
	/**
	 * RXgN^
	 * @param bstream oCg
	 */
	public KeywordLocationArray(byte[] bstream) {
		super(bstream);
	}
	/**
	 * RXgN^
	 * @param locations ʒu̔z
	 */
	public KeywordLocationArray(KeywordLocation[] locations) {
		add(locations);
	}
	/**
	 * XgɈʒuǉ
	 * @param location ʒu
	 */
	public void add(KeywordLocation location) {
		((KeywordLocationArrayListByteStream)o).add(location);
	}
	/**
	 * XgɈʒuǉ
	 * z̓eSĒǉ
	 * @param locations ǉʒu̔z
	 */
	public void add(KeywordLocation[] locations) {
		for(int i = 0; i < locations.length; i++) {
			add(locations[i]);
		}
	}
	/**
	 * i[ĂʒũCe[^Ԃ
	 * @return Ce[^
	 */
	public Iterator iterator() {
		return ((KeywordLocationArrayListByteStream)o).iterator();
	}
	/**
	 * i[ĂʒuzŕԂ
	 * @return z
	 */
	public KeywordLocation[] toArray() {
		return (KeywordLocation[])((KeywordLocationArrayListByteStream)o).toArray(new KeywordLocation[0]);
	}

	/**
	 * R[hTCYԂ
	 * @return int R[hTCY
	 */
	public int getRecordSize() {
		KeywordLocation[] locations = toArray();
		int size = 4;				// z̗vfi[邽߂int̃TCY
		for(int i = 0; i < locations.length; i++) {
			size += locations[i].getRecordSize();
		}
		
		return size;
	}

	/**
	 * R[hlr
	 * @param o rΏ
	 * @return true: / false:Ⴄ
	 */
	public boolean equals(Object o) {
		// TODO ꂽ\bhEX^u
		return false;
	}

	/**
	 * oCg񂩂lIuWFNg𕜌
	 * ̃\bh́ChNXŎ
	 * @param bstream oCg
	 * @throws IllegalArgumentException oCg񂩂̒lIuWFNg̕Ɏs
	 */
	protected void createObjectFromByteStream(byte[] bstream) throws IllegalArgumentException {
		o = new KeywordLocationArrayListByteStream(bstream);
	}
}

==> fts-1.6.zip: fts/src/org/logical_paradox/fts/KeywordLocationArray.java <==
/*
 * KeywordLocationzƂĊǗRNV
 */
package org.logical_paradox.fts;

import java.util.Iterator;

import org.logical_paradox.common.vrm.Record;

/**
 * KeywordLocationzŊǗRNV
 * ̃RNV̂Record̃TuNXƂāCVRMňƂł
 * 
 * @author satoshi akabane@logical-paradox.org
 * @version 1.0
 */
public class KeywordLocationArray extends Record {
	/**
	 * RXgN^
	 */
	public KeywordLocationArray() {
		o = new KeywordLocationArrayListByteStream();
	}
	/**
	 * RXgN^
	 * @param bstream oCg
	 */
	public KeywordLocationArray(byte[] bstream) {
		super(bstream);
	}
	/**
	 * RXgN^
	 * @param locations ʒu̔z
	 */
	public KeywordLocationArray(KeywordLocation[] locations) {
		add(locations);
	}
	/**
	 * XgɈʒuǉ
	 * @param location ʒu
	 */
	public void add(KeywordLocation location) {
		((KeywordLocationArrayListByteStream)o).add(location);
	}
	/**
	 * XgɈʒuǉ
	 * z̓eSĒǉ
	 * @param locations ǉʒu̔z
	 */
	public void add(KeywordLocation[] locations) {
		for(int i = 0; i < locations.length; i++) {
			add(locations[i]);
		}
	}
	/**
	 * XgɈʒuǉ
	 * w肳ꂽʒuzSĒǉ
	 * @param locations ʒuz
	 */
	public void add(KeywordLocationArray locations) {
		add(locations.toArray());
	}
	/**
	 * i[ĂʒũCe[^Ԃ
	 * @return Ce[^
	 */
	public Iterator iterator() {
		return ((KeywordLocationArrayListByteStream)o).iterator();
	}
	/**
	 * i[ĂʒuzŕԂ
	 * @return z
	 */
	public KeywordLocation[] toArray() {
		return (KeywordLocation[])((KeywordLocationArrayListByteStream)o).toArray(new KeywordLocation[0]);
	}

	/**
	 * R[hTCYԂ
	 * @return int R[hTCY
	 */
	public int getRecordSize() {
		KeywordLocation[] locations = toArray();
		int size = 4;				// z̗vfi[邽߂int̃TCY
		for(int i = 0; i < locations.length; i++) {
			size += locations[i].getRecordSize();
		}
		
		return size;
	}

	/**
	 * R[hlr
	 * @param o rΏ
	 * @return true: / false:Ⴄ
	 */
	public boolean equals(Object o) {
		// TODO ꂽ\bhEX^u
		return false;
	}

	/**
	 * oCg񂩂lIuWFNg𕜌
	 * ̃\bh́ChNXŎ
	 * @param bstream oCg
	 * @throws IllegalArgumentException oCg񂩂̒lIuWFNg̕Ɏs
	 */
	protected void createObjectFromByteStream(byte[] bstream) throws IllegalArgumentException {
		o = new KeywordLocationArrayListByteStream(bstream);
	}
}
